@@ -1,6 +1,5 @@
 from . import GIT
-from ..program import ARGS
-from ..program import PROGRAM
+from ..program import ARGS, PROGRAM
 
 COMMIT_ID_LENGTH = 7
 
